<?php

	// we want to increase the execution time for time consuming conversions
	// 4 min is the maximum
	set_time_limit(240);


	// Include the main TCPDF library (search for installation path).
	require_once('tcpdf_include.php');

	// create new PDF document
	$pdf = new TCPDF(PDF_PAGE_ORIENTATION, PDF_UNIT, PDF_PAGE_FORMAT, true, 'UTF-8', false);

	// set document information
	//$pdf->SetCreator(PDF_CREATOR);
	$pdf->SetAuthor('CADViewer JS');
	$pdf->SetTitle('CADViewer JS');
	$pdf->SetSubject('Batch Print');
	//$pdf->SetKeywords('TCPDF, PDF, example, test, guide');

	// set default header data
	//$pdf->SetHeaderData("", 0, CADViewer JS Batch Print, "");

	$pdf->SetHeaderData('', PDF_HEADER_LOGO_WIDTH, 'CADViewer JS', 'Batch Print');


	// set header and footer fonts
	//$pdf->setHeaderFont(Array(PDF_FONT_NAME_MAIN, '', PDF_FONT_SIZE_MAIN));
	//$pdf->setFooterFont(Array(PDF_FONT_NAME_DATA, '', PDF_FONT_SIZE_DATA));

	// set default monospaced font
	$pdf->SetDefaultMonospacedFont(PDF_FONT_MONOSPACED);

	// set margins
	$pdf->SetMargins(PDF_MARGIN_LEFT, PDF_MARGIN_TOP, PDF_MARGIN_RIGHT);
	$pdf->SetHeaderMargin(PDF_MARGIN_HEADER);
	$pdf->SetFooterMargin(PDF_MARGIN_FOOTER);

	// set auto page breaks
	$pdf->SetAutoPageBreak(TRUE, PDF_MARGIN_BOTTOM);

	// set image scale factor
	$pdf->setImageScale(PDF_IMAGE_SCALE_RATIO);

	// set some language-dependent strings (optional)
	if (@file_exists(dirname(__FILE__).'/lang/eng.php')) {
		require_once(dirname(__FILE__).'/lang/eng.php');
		$pdf->setLanguageArray($l);
	}

	// -------------------------------------------------------------------


	$serverPath = $_POST['serverPath'];
	$numberOfFiles = $_POST['numberOfFiles'];

	try {

		for ($i = 0; $i < $numberOfFiles; $i++) {
			$file_id = "fileName_". $i;
			$fileNameArray[$i] = $_POST[$file_id];

			$rot_id = "rotation_". $i;
			$rotationArray[$i] = $_POST[$rot_id];

			$paper_id = "page_format_". $i;
			$paperSizeArray[$i] = $_POST[$paper_id];

			$resolution_id = "page_resolution_". $i;
			$pageResolutionArray[$i] = $_POST[$resolution_id];

			$base64_string = file_get_contents('./' . $fileNameArray[$i] . '_base64.png');
			$data = explode(',', $base64_string);
			$output_file = $fileNameArray[$i] .'.png';

			$ifp = fopen($output_file, "wb");
			fwrite($ifp, base64_decode($data[1]));
			fclose($ifp);

			unlink($fileNameArray[$i] . '_base64.png');
		}
	} catch (Exception $e) {
		echo 'Caught exception 1: ',  $e->getMessage(), "\n";
	}


	try {

		for ($i = 0; $i < $numberOfFiles; $i++) {
			$rotateFilename = $fileNameArray[$i] . '.png' ; // PATH
			$degrees = 90;

			if ( strcmp('portrait', $rotationArray[$i]) == 0){
				// do nothing
			}
			else{
				//$fileType = strtolower(substr('your_image.image_type', strrpos('your_image.image_type', '.') + 1));
				$fileType = 'png';
				if($fileType == 'png' || $fileType == 'PNG'){
				   header('Content-type: image/png');
				   $source = imagecreatefrompng($rotateFilename);
				   $bgColor = imagecolorallocatealpha($source, 255, 255, 255, 127);
				   // Rotate
				   $rotate = imagerotate($source, $degrees, $bgColor);
				   imagesavealpha($rotate, true);
				   imagepng($rotate,$rotateFilename);
				}

				if($fileType == 'jpg' || $fileType == 'jpeg'){
				   header('Content-type: image/jpeg');
				   $source = imagecreatefromjpeg($rotateFilename);
				   // Rotate
				   $rotate = imagerotate($source, $degrees, 0);
				   imagejpeg($rotate,$rotateFilename);
				}
				// Free the memory
				imagedestroy($source);
				imagedestroy($rotate);
			}
		}
	} catch (Exception $e) {
		echo 'Caught exception 2: ',  $e->getMessage(), "\n";
	}



	try {
		for ($i = 0; $i < $numberOfFiles; $i++) {


			$pdf->resetHeaderTemplate();
			$pdf->SetHeaderData('', PDF_HEADER_LOGO_WIDTH, 'CADViewer JS', 'Drawing: '. $fileNameArray[$i] . '       Resolution: ' . $pageResolutionArray[$i] . 'dpi');

			// add a page
//			$pdf->AddPage('P', 'A4');
			$pdf->AddPage('P', $paperSizeArray[$i]);

//			$pdf->Image($fileNameArray[$i] . '.png' , '', '', '', '', 'PNG', '', '', true, 300, '', false, false, 1, false, false, false);
			$pdf->Image($fileNameArray[$i] . '.png' , '', '', '', '', 'PNG', '', '', true, $pageResolutionArray[$i], '', false, false, 0, false, false, false);
			unlink($fileNameArray[$i] . '.png');
		}

	} catch (Exception $e) {
		echo 'Caught exception 3: ',  $e->getMessage(), "\n";
	}




	$randomNr = rand(100, 100000);
	$final_fileName = 'batch_' . $randomNr . '.pdf';

	//Close and output PDF document
	$pdf->Output(__DIR__ . '/files/' . $final_fileName, 'F');

	$html_content = '<!DOCTYPE html><html><title>CADViewer JS - Print</title><head>';
	$html_content = $html_content . '<script src="../javascripts/jquery-2.2.3.js" type="text/javascript"></script>';

	$html_content = $html_content . '<script type="text/javascript">$(window).on(\'beforeunload\', function (){ $.ajax({url:\''. '../delete-file.php?file=./files/batch_' . $randomNr . '.pdf'  . '\', cache: false, success: function(html){}}); $.ajax({url:\''. '../delete-file.php?file=./files/batch_' . $randomNr . '.html'  . '\', cache: false, success: function(html){}}) });';
	$html_content = $html_content . '$(window).on(\'unload\', function (){ $.ajax({url:\''. '../delete-file.php?file=./files/batch_' . $randomNr . '.pdf'  . '\', cache: false, success: function(html){}}); $.ajax({url:\''. '../delete-file.php?file=./files/batch_' . $randomNr . '.html'  . '\', cache: false, success: function(html){}}) });';
	$html_content = $html_content . 'window.onbeforeunload = function (){ $.ajax({url:\''. '../delete-file.php?file=./files/batch_' . $randomNr . '.pdf'  . '\', cache: false, success: function(html){}}); $.ajax({url:\''. '../delete-file.php?file=./files/batch_' . $randomNr . '.html'  . '\', cache: false, success: function(html){}}) };';

	$html_content = $html_content .  '</script><body><div id="pdf"><object width="1654" height="2339" type="application/pdf" data="' . $final_fileName . '" id="pdf_content"><p>Please install a PDF viewer, the CADViewer JS batch file PDF cannot be displayed.</p></object></div></body></html>';



//	$html_content = $html_content . '<script type="text/javascript">$(window).on(\'beforeunload\', function (){ $.ajax({url:\''. './delete-file.php?file=batch_' . $randomNr . '.pdf'  . '\', cache: false, success: function(html){}}); $.ajax({url:\''. './delete-file.php?file=batch_' . $randomNr . '.html'  . '\', cache: false, success: function(html){}}) });';
//	$html_content = $html_content . '$(window).on(\'unload\', function (){ $.ajax({url:\''. './delete-file.php?file=batch_' . $randomNr . '.pdf'  . '\', cache: false, success: function(html){}}); $.ajax({url:\''. './delete-file.php?file=batch_' . $randomNr . '.html'  . '\', cache: false, success: function(html){}}) });';
//	$html_content = $html_content . 'window.onbeforeunload = function (){ $.ajax({url:\''. './delete-file.php?file=batch_' . $randomNr . '.pdf'  . '\', cache: false, success: function(html){}}); $.ajax({url:\''. './delete-file.php?file=batch_' . $randomNr . '.html'  . '\', cache: false, success: function(html){}}) };';




//	$html_content = $html_content . '<body><div id="pdf"><object width="1654" height="2339" type="application/pdf" data="' . $final_fileName . '" id="pdf_content"><p>Please install a PDF viewer, the CADViewer JS batch file PDF cannot be displayed.</p></object></div></body></html>';
	// $html_content = '<!DOCTYPE html><html><head><title>CADViewer JS - Print</title></head><body><div id="pdf"><object width="1654" height="2339" type="application/pdf" data="' . $final_fileName . '" id="pdf_content"><p>Please install a PDF viewer, the CADViewer JS batch file PDF cannot be displayed.</p></object></div></body></html>';


	$html_file = './files/batch_' . $randomNr . '.html';

	$ifp = fopen($html_file, "wb");
	fwrite($ifp, $html_content);
	fclose($ifp);

	echo $html_file;
	exit;


?>